@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.008';     # TRIAL VERSION
+our $VERSION = '0.009';     # TRIAL VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -127,7 +127,44 @@ sub _new_service {
 #pod containing the results of the SOAP call; in list context they return the
 #pod results hashref and an
 #pod L<XML::Compile::SOAP::Trace|XML::Compile::SOAP::Trace>
-#pod object suitable for debugging and exception handling.
+#pod object suitable for debugging and exception handling. If there is no result
+#pod then an exception will be thrown.
+#pod
+#pod Please consult the
+#pod L<Avalara SOAP API reference|http://developer.avalara.com/api-reference>
+#pod for semantic details on the methods, parameters and results available for each
+#pod of the methods listed below. Note that in order to make this interface easier
+#pod and more Perl-ish, the following changes have been made:
+#pod
+#pod =over
+#pod
+#pod =item *
+#pod
+#pod SOAP operation names have been transformed from C<CamelCase> to
+#pod C<lowercase_with_underscores>. For example, C<GetTax> is now
+#pod L</get_tax>.
+#pod
+#pod =item *
+#pod
+#pod Parameters do not need to be enclosed in C<{parameters}{FooRequest}{ ... }>
+#pod hashes of hashes. These will be automatically added for you, along with all
+#pod necessary SOAP headers. The examples below reflect this.
+#pod
+#pod =item *
+#pod
+#pod Similarly, results are not enclosed in C<{parameters}{FooResult}{ ... }>
+#pod hashes of hashes. They are, however, returned as a hash reference, not a
+#pod simple hash. If you want access to other aspects of the SOAP response, make
+#pod the call in list context and the second value in the list will be an
+#pod L<XML::Compile::SOAP::Trace|XML::Compile::SOAP::Trace>
+#pod instance with methods for retrieving the full request and response as
+#pod L<HTTP::Request|HTTP::Request> and
+#pod L<HTTP::Response|HTTP::Response> objects,
+#pod along with other methods for doing things like retrieving the parsed
+#pod L<XML::LibXML::Document|XML::LibXML::Document> DOM
+#pod node of the response.
+#pod
+#pod =back
 #pod
 #pod =for Pod::Coverage BUILD
 #pod
@@ -205,15 +242,11 @@ sub _method_closure {
             },
         );
 
-        #pod =pod
-        #pod
-        #pod If there is no result then an exception will be thrown.
-        #pod
-        #pod =cut
-
         if ( not $answer_ref ) {
             for ( $trace->errors ) { $_->throw }
         }
+        $answer_ref
+            = $answer_ref->{parameters}{ $operation->name . 'Result' };
         return wantarray ? ( $answer_ref, $trace ) : $answer_ref;
     };
 }
@@ -235,7 +268,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -268,7 +301,44 @@ necessary parameters. In scalar context they return a reference to a hash
 containing the results of the SOAP call; in list context they return the
 results hashref and an
 L<XML::Compile::SOAP::Trace|XML::Compile::SOAP::Trace>
-object suitable for debugging and exception handling.
+object suitable for debugging and exception handling. If there is no result
+then an exception will be thrown.
+
+Please consult the
+L<Avalara SOAP API reference|http://developer.avalara.com/api-reference>
+for semantic details on the methods, parameters and results available for each
+of the methods listed below. Note that in order to make this interface easier
+and more Perl-ish, the following changes have been made:
+
+=over
+
+=item *
+
+SOAP operation names have been transformed from C<CamelCase> to
+C<lowercase_with_underscores>. For example, C<GetTax> is now
+L</get_tax>.
+
+=item *
+
+Parameters do not need to be enclosed in C<{parameters}{FooRequest}{ ... }>
+hashes of hashes. These will be automatically added for you, along with all
+necessary SOAP headers. The examples below reflect this.
+
+=item *
+
+Similarly, results are not enclosed in C<{parameters}{FooResult}{ ... }>
+hashes of hashes. They are, however, returned as a hash reference, not a
+simple hash. If you want access to other aspects of the SOAP response, make
+the call in list context and the second value in the list will be an
+L<XML::Compile::SOAP::Trace|XML::Compile::SOAP::Trace>
+instance with methods for retrieving the full request and response as
+L<HTTP::Request|HTTP::Request> and
+L<HTTP::Response|HTTP::Response> objects,
+along with other methods for doing things like retrieving the parsed
+L<XML::LibXML::Document|XML::LibXML::Document> DOM
+node of the response.
+
+=back
 
 =head2 new
 
@@ -279,18 +349,95 @@ that can be set at construction.
 
 =head2 get_tax
 
-Example:
+Constructing and making an example request:
 
-    my ( $answer_ref, $trace ) = $avatax->get_tax(
-        CustomerCode => 'ABC4335',
-        DocDate      => '2014-01-01',
-        CompanyCode  => 'APITrialCompany',
-        DocCode      => 'INV001',
-        DetailLevel  =>  'Tax',
-        Commit       => 0,
-        DocType      => 'SalesInvoice',
+    my %get_tax_request = (
+        CompanyCode         => 'APITrialCompany',
+        DocType             => 'SalesInvoice',
+        DocCode             => 'INV001',
+        DocDate             => '2014-01-01',
+        CustomerCode        => 'ABC4335',
+        Discount            => 0,
+        OriginCode          => 0,
+        DestinationCode     => 1,
+        DetailLevel         => 'Tax',
+        HashCode            => 0,
+        Commit              => 'false',
+        ServiceMode         => 'Automatic',
+        PaymentDate         => '1900-01-01',
+        ExchangeRate        => 1,
+        ExchangeRateEffDate => '1900-01-01',
     );
 
+    my @addresses = (
+        {   Line1       => '45 Fremont Street',
+            City        => 'San Francisco',
+            Region      => 'CA',
+            PostalCode  => '94105-2204',
+            Country     => 'US',
+            TaxRegionId => 0,
+        },
+        {   Line1       => '118 N Clark St',
+            Line2       => 'ATTN Accounts Payable',
+            City        => 'Chicago',
+            Region      => 'IL',
+            PostalCode  => '60602-1304',
+            Country     => 'US',
+            TaxRegionId => 0,
+        },
+        {   Line1       => '100 Ravine Lane',
+            City        => 'Bainbridge Island',
+            Region      => 'WA',
+            PostalCode  => '98110',
+            Country     => 'US',
+            TaxRegionId => 0,
+        },
+    );
+    for my $address_code (0 .. @addresses) {
+        push @{$get_tax_request{Addresses}{BaseAddress}} => {
+            AddressCode => $address_code,
+            %{ $addresses[$address_code] },
+        };
+    }
+
+    my @lines => (
+        {   OriginCode      => 0,
+            DestinationCode => 1,
+            ItemCode        => 'N543',
+            TaxCode         => 'NT',
+            Qty             => 1,
+            Amount          => 10,
+            Discounted      => 'false',
+            Description     => 'Red Size 7 Widget',
+        },
+        {   OriginCode      => 0,
+            DestinationCode => 2,
+            ItemCode        => 'T345',
+            TaxCode         => 'PC030147',
+            Qty             => 3,
+            Amount          => 150,
+            Discounted      => 'false',
+            Description     => 'Size 10 Green Running Shoe',
+        },
+        {   OriginCode      => 0,
+            DestinationCode => 2,
+            ItemCode        => 'FREIGHT',
+            TaxCode         => 'FR',
+            Qty             => 1,
+            Amount          => 15,
+            Discounted      => 'false',
+            Description     => 'Shipping Charge',
+        },
+    );
+    for my $line_no (0 .. $#lines) {
+        push @{$get_tax_request{Lines}{Line}} => {
+            No => $line_no,
+            %{ $lines[$line_no - 1] },
+        };
+    }
+
+    my ( $answer_ref, $trace ) = $avatax->get_tax(%get_tax_request);
+
 =head2 post_tax
 
 Example:
@@ -503,15 +650,11 @@ Example:
 
     use List::Util 1.33 'any';
     my ( $answer_ref, $trace ) = $avatax->ping;
-    for my $code ( $result_ref->{parameters}{PingResult}{ResultCode} ) {
-        if ( $code eq 'Success' ) { say $code; last }
-        if ( $code eq 'Warning' ) {
-            warn $result_ref->{parameters}{PingResult}{Messages};
-            last;
-        }
-        if ( any {$code eq $_} qw(Error Exception) ) {
-            die $result_ref->{parameters}{PingResult}{Messages};
-        }
+    for my $code ( $answer_ref->{ResultCode} ) {
+        if ( $code eq 'Success' ) { say $code;                    last }
+        if ( $code eq 'Warning' ) { warn $answer_ref->{Messages}; last }
+
+        die $answer_ref->{Messages} if any {$code eq $_} qw(Error Exception);
     }
 
 =head2 tax_summary_fetch
@@ -629,8 +772,6 @@ order to debug or extend this module.
 
 =for Pod::Coverage BUILD
 
-If there is no result then an exception will be thrown.
-
 =head1 SUPPORT
 
 =head2 Perldoc
